<?php

declare(strict_types=1);

namespace apexl\Aura\SqlQuery;

class Quoter extends \Aura\SqlQuery\Mysql\Quoter
{
    public function quoteNamesIn($text): string
    {
        return $text;
    }
}
